==> muse_0.5.2.orig.tar.gz: muse-0.5.2/widgets/ctrlcombo.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: ctrlcombo.cpp,v 1.1 2002/01/30 14:54:03 muse Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#include "ctrlcombo.h"

//---------------------------------------------------------
//   CtrlComboBox
//---------------------------------------------------------

CtrlComboBox::CtrlComboBox(QWidget* parent, const char* name = 0)
   : QComboBox(parent, name)
      {
      const char* ctxt[] = {
            "No Ctrl",    "BankSelMSB", "Modulation",  "BreathCtrl",
            "Control 3",  "Foot Ctrl",  "Porta Time",  "DataEntMSB",
            "MainVolume", "Balance",    "Control 9",   "Pan",
            "Expression", "Control 12", "Control 13",  "Control 14",
            "Control 15", "Gen.Purp.1", "Gen.Purp.2",  "Gen.Purp.3",
            "Gen.Purp.4", "Control 20", "Control 21",  "Control 22",
            "Control 23", "Control 24", "Control 25",  "Control 26",
            "Control 27", "Control 28", "Control 29",  "Control 30",
            "Control 31", "BankSelLSB", "Modul. LSB",  "BrthCt.LSB",
            "Control 35", "FootCt.LSB", "Port.T LSB",  "DataEntLSB",
            "MainVolLSB", "BalanceLSB", "Control 41",  "Pan LSB",
            "Expr. LSB",  "Control 44", "Control 45",  "Control 46",
            "Control 47", "Gen.P.1LSB", "Gen.P.2LSB",  "Gen.P.3LSB",
            "Gen.P.4LSB", "Control 52", "Control 53",  "Control 54",
            "Control 55", "Control 56", "Control 57",  "Control 58",
            "Control 59", "Control 60", "Control 61",  "Control 62",
            "Control 63", "Sustain",    "Porta Ped",   "Sostenuto",
            "Soft Pedal", "Control 68", "Hold 2",      "Control 70",
            "HarmonicCo", "ReleaseTime", "Attack Time", "Brightness",
            "Control 75", "Control 76", "Control 77",  "Control 78",
            "Control 79", "Gen.Purp.5", "Gen.Purp.6",  "Gen.Purp.7",
            "Gen.Purp.8", "Porta Ctrl", "Control 85",  "Control 86",
            "Control 87", "Control 88", "Control 89",  "Control 90",
            "Effect1Dep", "Effect2Dep", "Effect3Dep",  "Effect4Dep",
            "Phaser Dep", "Data Incr",  "Data Decr",   "NRPN LSB",
            "NRPN MSB",   "RPN LSB",    "RPN MSB",     "Control102",
            "Control103", "Control104", "Control105",  "Control106",
            "Control107", "Control108", "Control109",  "Control110",
            "Control111", "Control112", "Control113",  "Control114",
            "Control115", "Control116", "Control117",  "Control118",
            "Control119", "AllSndOff",  "Reset Ctrl",  "Local Ctrl",
            "AllNoteOff", "OmniModOff", "OmniModeOn",  "MonoModeOn",
            "PolyModeOn"
            };
      for (unsigned int i = 0; i < sizeof(ctxt)/sizeof(*ctxt); ++i)
            insertItem(ctxt[i]);
      }

==> muse_0.6.3.orig.tar.gz: muse-0.6.3/widgets/ctrlcombo.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//  $Id: ctrlcombo.cpp,v 1.1.1.1 2003/10/29 10:06:32 wschweer Exp $
//
//  (C) Copyright 1999/2000 Werner Schweer (ws@seh.de)
//=========================================================

#include "ctrlcombo.h"

//---------------------------------------------------------
//   CtrlComboBox
//---------------------------------------------------------

CtrlComboBox::CtrlComboBox(QWidget* parent, const char* name)
   : QComboBox(parent, name)
      {
      const char* ctxt[] = {
            "No Ctrl",    "BankSelMSB", "Modulation",  "BreathCtrl",
            "Control 3",  "Foot Ctrl",  "Porta Time",  "DataEntMSB",
            "MainVolume", "Balance",    "Control 9",   "Pan",
            "Expression", "Control 12", "Control 13",  "Control 14",
            "Control 15", "Gen.Purp.1", "Gen.Purp.2",  "Gen.Purp.3",
            "Gen.Purp.4", "Control 20", "Control 21",  "Control 22",
            "Control 23", "Control 24", "Control 25",  "Control 26",
            "Control 27", "Control 28", "Control 29",  "Control 30",
            "Control 31", "BankSelLSB", "Modul. LSB",  "BrthCt.LSB",
            "Control 35", "FootCt.LSB", "Port.T LSB",  "DataEntLSB",
            "MainVolLSB", "BalanceLSB", "Control 41",  "Pan LSB",
            "Expr. LSB",  "Control 44", "Control 45",  "Control 46",
            "Control 47", "Gen.P.1LSB", "Gen.P.2LSB",  "Gen.P.3LSB",
            "Gen.P.4LSB", "Control 52", "Control 53",  "Control 54",
            "Control 55", "Control 56", "Control 57",  "Control 58",
            "Control 59", "Control 60", "Control 61",  "Control 62",
            "Control 63", "Sustain",    "Porta Ped",   "Sostenuto",
            "Soft Pedal", "Control 68", "Hold 2",      "Control 70",
            "HarmonicCo", "ReleaseTime", "Attack Time", "Brightness",
            "Control 75", "Control 76", "Control 77",  "Control 78",
            "Control 79", "Gen.Purp.5", "Gen.Purp.6",  "Gen.Purp.7",
            "Gen.Purp.8", "Porta Ctrl", "Control 85",  "Control 86",
            "Control 87", "Control 88", "Control 89",  "Control 90",
            "Effect1Dep", "Effect2Dep", "Effect3Dep",  "Effect4Dep",
            "Phaser Dep", "Data Incr",  "Data Decr",   "NRPN LSB",
            "NRPN MSB",   "RPN LSB",    "RPN MSB",     "Control102",
            "Control103", "Control104", "Control105",  "Control106",
            "Control107", "Control108", "Control109",  "Control110",
            "Control111", "Control112", "Control113",  "Control114",
            "Control115", "Control116", "Control117",  "Control118",
            "Control119", "AllSndOff",  "Reset Ctrl",  "Local Ctrl",
            "AllNoteOff", "OmniModOff", "OmniModeOn",  "MonoModeOn",
            "PolyModeOn"
            };
      for (unsigned int i = 0; i < sizeof(ctxt)/sizeof(*ctxt); ++i)
            insertItem(QString(ctxt[i]));
      }
